require 'helper'

class TestSpec1Goto < MiniTest::Unit::TestCase
  def load_program_with_scripts(scripts, starting_script)
    Program.new(version: GuidedPath::Parser::Spec1, scripts: Hash[scripts.collect { |name, filename| [name, load_fixture("spec1/#{filename}")]}] , starting_script: starting_script) 
  end

  def load_program_fixture(spec_name)
    load_program_with_scripts({'test' => spec_name}, 'test')

  end

  def test_simple_goto_nodes
    @program = load_program_fixture("goto_simple_jumps.yml")
    assert_nodes_equal @program, {TextNode => 3, GotoNode => 2}

    assert_equal "Let's start here.", @program.starting_node.value
    assert_kind_of GotoNode, @program.starting_node.next_node
    assert_equal "Let's loop some!", @program.starting_node.next_node.next_node.value
    assert_kind_of GotoNode, @program.starting_node.next_node.next_node.next_node
    assert_equal "Let's start here.", @program.starting_node.next_node.next_node.next_node.next_node.value
  end

  def test_simple_node_jumps
    @program = load_program_fixture("goto_node_jumps.yml")
    assert_nodes_equal @program, {TextNode => 3}

    assert_equal "Let's start here.", @program.starting_node.value
    assert_equal "Let's loop some!", @program.starting_node.next_node.value
    assert_equal "Let's start here.", @program.starting_node.next_node.next_node.value
  end

  def test_cross_script_jumps
    @program = load_program_with_scripts({'scripta' => 'goto_jump_script_a.yml', 'scriptb' => 'goto_jump_script_b.yml'}, 'scripta')

    assert_equal "Hey there!", @program.starting_node.value
    assert_equal "On target!", @program.starting_node.next_node.value
    assert_equal "Hey there!", @program.starting_node.next_node.next_node.next_node.value
  end
end




